//
//  ServiceProvider.swift
//  top-shelf
//
//  Created by Jake Marsh on 2/9/16.
//  Copyright © 2016 jakemarsh. All rights reserved.
//

import Foundation
import TVServices

struct Spaceship {
  let identifier: String
  let name: String
  let imageURL: String
}

extension Spaceship {
  func asTVContentItem(containerID: TVContentIdentifier) -> TVContentItem? {
    guard let itemID = TVContentIdentifier(identifier: identifier, container: containerID) else { return nil }
    guard let item = TVContentItem(contentIdentifier: itemID) else { return nil }

    item.imageURL = NSURL(string: imageURL)!
    item.imageShape = .HDTV
    item.title = name
    item.displayURL = NSURL(string: "spaceships://ship/\(identifier)")
    item.playURL = NSURL(string: "spaceships://ship/\(identifier)")
    
    return item
  }
}

func recentlyLaunchedShips() -> [Spaceship] {
  return [
    Spaceship(identifier: "mf", name: "Millennium Flacon", imageURL: "http://img.lum.dolimg.com/v1/images/Millennium-Falcon_018ea796.jpeg?region=0%2C49%2C1536%2C768"),
    Spaceship(identifier: "t4", name: "Tantive IV", imageURL: "http://vignette1.wikia.nocookie.net/starwars/images/1/12/MP-Tantive.png/revision/latest?cb=20140412000103"),
    Spaceship(identifier: "s1", name: "Slave I", imageURL: "http://vignette1.wikia.nocookie.net/starwars/images/b/b4/Slave1.jpg/revision/latest?cb=20070720175658"),
    Spaceship(identifier: "o", name: "Outrider", imageURL: "http://vignette3.wikia.nocookie.net/starwars/images/1/1c/Outrider.jpg/revision/latest?cb=20061215022956"),
    Spaceship(identifier: "g", name: "Ghost", imageURL: "http://a.dilcdn.com/bl/wp-content/uploads/sites/6/2014/09/Rebels_Ghost.png"),
    Spaceship(identifier: "t1138", name: "Transport 1138", imageURL: "http://vignette3.wikia.nocookie.net/starwars/images/e/e6/Rebel_transport_box_art.jpg/revision/latest?cb=20140916032031")
  ]
}

class ServiceProvider: NSObject, TVTopShelfProvider {

  override init() {
      super.init()
  }

  // MARK: - TVTopShelfProvider protocol

  var topShelfStyle: TVTopShelfContentStyle {
    return .Sectioned
  }

  var topShelfItems: [TVContentItem] {
    guard let sectionID = TVContentIdentifier(identifier: "top-shelf", container: nil) else { return [] }
    guard let shipsSection = TVContentItem(contentIdentifier: sectionID) else { return [] }

    shipsSection.title = "Recent Launches"
    shipsSection.topShelfItems = recentlyLaunchedShips()
      .map { $0.asTVContentItem(sectionID) }
      .flatMap { $0 } // remove potential empty Optionals

    return [shipsSection]
  }
}
